@@ -58,6 +58,7 @@ class EcotrustAPI:
         self.sess = Session()
         self.instancia_base_url = instancia_url[:-1] if instancia_url[-1] == '/' else instancia_url
         self.endpoints = {}
+        self.ultimo_scan = None
 
         retries = Retry(total=5,
                         backoff_factor=0.1,
@@ -265,15 +266,22 @@ class EcotrustAPI:
         
     """
     def obter_reporte_se_disponivel(self, scan_titulo: str) -> Tuple[bool, dict | str]:
-        scan_id = self.__obter_ultimo_scan(scan_titulo)
-        scan = self.__obter_scan_by_id(scan_id['id'])
+
+        # Não obtenha o dataset novamente, caso já tenha sido obtido
+        if self.ultimo_scan and self.ultimo_scan.get('title', '') == scan_titulo:
+            scan_obj = self.ultimo_scan
+        else:
+            scan_obj = self.__obter_ultimo_scan(scan_titulo)
+            self.ultimo_scan = scan_obj
+
+        scan = self.__obter_scan_by_id(scan_obj['id'])
 
         if scan['status'] in ['started', 'enqueued']:
             return False, ''
         if scan['status'] == 'error':
             return False, 'Scan falhou'
         if scan['status'] == 'finished':
-            __, rel_ou_erro = self.obter_relatorio_json(scan_id['id'])
+            __, rel_ou_erro = self.obter_relatorio_json(scan_obj['id'])
 
             if type(rel_ou_erro) != dict:
                 return False, rel_ou_erro
